@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ ContactPrintThemePreview::ContactPrintThemePreview(const QString &projectDirecto
     : GrantleeThemeEditor::PreviewWidget(parent)
 {
     QHBoxLayout *hbox = new QHBoxLayout(this);
-    hbox->setMargin(0);
+    hbox->setContentsMargins(0, 0, 0, 0);
     mViewer = new QWebEngineView(this);
     mViewer->setContextMenuPolicy(Qt::NoContextMenu);
     hbox->addWidget(mViewer);
